macro_rules! syscall {
($function_name:expr, $($y:expr), +) => { ... };
}Expand description
Macro to perform a system call (syscall) by dynamically resolving its function name.
Arguments
$function_name- A string slice representing the name of the syscall function (e.g.,"NtQueryInformationProcess").$($args:expr),+- A variadic list of arguments to pass to the syscall.
Example
ⓘ
syscall!("NtQueryInformationProcess", process_handle, process_info_class, process_info, process_info_length, return_length);